Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Transport ¶
type Transport interface {
// Receive gets a channel on which to receive messages
// with the specified name.
Receive(name string) <-chan []byte
// Send gets a channel on which messages with the
// specified name may be sent.
Send(name string) chan<- []byte
// ErrChan gets a channel through which errors
// are sent.
ErrChan() <-chan error
// Stop stops the transport. The channel returned from Done() will be closed
// when the transport has stopped.
Stop()
// Done gets a channel which is closed when the
// transport has successfully stopped.
Done() chan struct{}
}
Transport provides message sending and receiving capabilities over a messaging queue technology. Clients should always check for errors coming through ErrChan.
Directories
¶
| Path | Synopsis |
|---|---|
|
example
|
|
|
greeter/client
command
|
|
|
greeter/service
command
|
|
|
queues
|
|
|
nats
Package nats provides a Vice implementation for NATS.
|
Package nats provides a Vice implementation for NATS. |
|
nsq
Package nsq provides a Vice implementation for NSQ.
|
Package nsq provides a Vice implementation for NSQ. |
|
redis
Package redis provides a Vice implementation for REDIS.
|
Package redis provides a Vice implementation for REDIS. |
|
sqs
Package sqs provides a Vice implementation for Amazon Simple Queue Service.
|
Package sqs provides a Vice implementation for Amazon Simple Queue Service. |
Click to show internal directories.
Click to hide internal directories.